# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`borgbackup`](#borgbackup): borg backup class
* [`borgbackup::git`](#borgbackup--git): Internal class to setup the git repository to store passphrase and key
* [`borgbackup::install`](#borgbackup--install): internal class borgbackup::install  internal class borgbackup::install to install the packages (used by ::borgbackup::server and ::borgbackup
* [`borgbackup::server`](#borgbackup--server): this class is used to setup a remote borg server (the target) where to put the backups

### Defined types

* [`borgbackup::addtogit`](#borgbackup--addtogit): internal define to add a repo to git.
* [`borgbackup::archive`](#borgbackup--archive): This class creates an archive in a repo
* [`borgbackup::authorized_key`](#borgbackup--authorized_key): Internal define to handle the authorized keys from borgbackup::server  for borgbackup dokumentation see:   http://borgbackup.readthedocs.io/e
* [`borgbackup::repo`](#borgbackup--repo): This class initializes a backup run

### Functions

* [`borgbackup::noop_connection`](#borgbackup--noop_connection): Set noop to true  for current and children scopes, if the socket on server port 22 cannot be opened.

### Tasks

* [`check`](#check): verifies the consistency of a borg repository and the corresponding archives
* [`info`](#info): displays detailed information about the borg repo
* [`list`](#list): lists the contents of the nodes borg repository

## Classes

### <a name="borgbackup"></a>`borgbackup`

borg backup class

#### Parameters

The following parameters are available in the `borgbackup` class:

* [`configdir`](#-borgbackup--configdir)
* [`ensure_ssh_directory`](#-borgbackup--ensure_ssh_directory)
* [`ssh_key_define`](#-borgbackup--ssh_key_define)
* [`ssh_key_res`](#-borgbackup--ssh_key_res)
* [`repos`](#-borgbackup--repos)
* [`default_target`](#-borgbackup--default_target)
* [`repos_defaults`](#-borgbackup--repos_defaults)
* [`archives`](#-borgbackup--archives)

##### <a name="-borgbackup--configdir"></a>`configdir`

Data type: `String`

configuration directory
defaults to '/etc/borgbackup'

Default value: `'/etc/borgbackup'`

##### <a name="-borgbackup--ensure_ssh_directory"></a>`ensure_ssh_directory`

Data type: `Boolean`

if we true (default) we create the .ssh directory

Default value: `true`

##### <a name="-borgbackup--ssh_key_define"></a>`ssh_key_define`

Data type: `Optional[String[1]]`

the resource to use for the generation of an ssh key
defaults to undef

Default value: `undef`

##### <a name="-borgbackup--ssh_key_res"></a>`ssh_key_res`

Data type: `Hash`

the parameters to use for the $ssh_key_define
defaults to {}

Default value: `{}`

##### <a name="-borgbackup--repos"></a>`repos`

Data type: `Hash`

Hash of repos to create (also see borgbackup::repo for
parameters.
defautls to {$::fqdn => {}} which creates an
empty repo named $::fqdn.
Hint: hiera5 will hash merge this parameter.

Default value: `{ $facts['networking']['fqdn'] => {} }`

##### <a name="-borgbackup--default_target"></a>`default_target`

Data type: `Optional[String[1]]`

the default target of the backup for $repos definition
defaults to undef
see ::borgbackup::repo

Default value: `undef`

##### <a name="-borgbackup--repos_defaults"></a>`repos_defaults`

Data type: `Hash`

default values for the $repos to create.
defaults to {}
Hint: hiera5 will hash merge this parameter.

Default value: `{}`

##### <a name="-borgbackup--archives"></a>`archives`

Data type: `Hash`

archives to add to $repos
hiera5 will hash merge this parameter.
Remark: these archives will bee added to all repos defined in
$repo. But can be overwriten per repo using $repo parameter.

Default value: `{}`

### <a name="borgbackup--git"></a>`borgbackup::git`

Internal class to setup the git repository to
store passphrase and key

#### Parameters

The following parameters are available in the `borgbackup::git` class:

* [`packages`](#-borgbackup--git--packages)
* [`gpg_keys`](#-borgbackup--git--gpg_keys)
* [`gpg_home`](#-borgbackup--git--gpg_home)
* [`gitrepo`](#-borgbackup--git--gitrepo)
* [`gitrepo_sshkey`](#-borgbackup--git--gitrepo_sshkey)
* [`git_home`](#-borgbackup--git--git_home)
* [`git_author`](#-borgbackup--git--git_author)

##### <a name="-borgbackup--git--packages"></a>`packages`

Data type: `Array`

the packages to ensure
defautls to ['git','gnupg']

Default value: `['git','gnupg']`

##### <a name="-borgbackup--git--gpg_keys"></a>`gpg_keys`

Data type: `Hash`

Hash of gpg public keys to use for the encryption of
password and keyfile.
the key for a pgp key must match the first email mentioned in
the key. otherwise it will reencrypt with each puppet run!
defaults to {}

Default value: `{}`

##### <a name="-borgbackup--git--gpg_home"></a>`gpg_home`

Data type: `String`

gpg directory to store pgp keys.
defaults to "${borgbackup::configdir}/.gnupg"

Default value: `"${borgbackup::configdir}/.gnupg"`

##### <a name="-borgbackup--git--gitrepo"></a>`gitrepo`

Data type: `Optional[String[1]]`

if set to a remote url, an existing git repo will be cloned and
commits will be pushed there. This gives the oportunity to have
a separate place to store the access keys to the backups.
defaults to undef which only creates a local git repo.
Remark: if you change this, you have localy adapt the
git repo (or delete it).

Default value: `undef`

##### <a name="-borgbackup--git--gitrepo_sshkey"></a>`gitrepo_sshkey`

Data type: `Optional[String[1]]`

ssh private key needed to access the gitrepo.
defaults to undef
if $gitrepo is not set this value is ignored.

Default value: `undef`

##### <a name="-borgbackup--git--git_home"></a>`git_home`

Data type: `String`

directory to clone or create the git repo for
keys and passphrases.
defaults to "${borgbackup::configdir}/git"

Default value: `"${borgbackup::configdir}/git"`

##### <a name="-borgbackup--git--git_author"></a>`git_author`

Data type: `String`

String to be used as git author for commits.
defaults to 'borgbackup <root@${::fqdn}>'

Default value: `'borgbackup <root@${::fqdn}>'`

### <a name="borgbackup--install"></a>`borgbackup::install`

internal class borgbackup::install

internal class borgbackup::install
to install the packages
(used by ::borgbackup::server and ::borgbackup)

#### Parameters

The following parameters are available in the `borgbackup::install` class:

* [`packages`](#-borgbackup--install--packages)
* [`package_ensure`](#-borgbackup--install--package_ensure)

##### <a name="-borgbackup--install--packages"></a>`packages`

Data type: `Array`

packages to install
defaults to ['borgbackup']

Default value: `['borgbackup']`

##### <a name="-borgbackup--install--package_ensure"></a>`package_ensure`

Data type: `String`

defaults to 'installed'

Default value: `'installed'`

### <a name="borgbackup--server"></a>`borgbackup::server`

this class is used to setup a remote borg server
(the target) where to put the backups

#### Parameters

The following parameters are available in the `borgbackup::server` class:

* [`backuproot`](#-borgbackup--server--backuproot)
* [`borguser`](#-borgbackup--server--borguser)
* [`borggroup`](#-borgbackup--server--borggroup)
* [`borghome`](#-borgbackup--server--borghome)
* [`user_ensure`](#-borgbackup--server--user_ensure)
* [`authorized_keys_target`](#-borgbackup--server--authorized_keys_target)
* [`authorized_keys_define`](#-borgbackup--server--authorized_keys_define)
* [`authorized_keys`](#-borgbackup--server--authorized_keys)
* [`authorized_keys_defaults`](#-borgbackup--server--authorized_keys_defaults)

##### <a name="-borgbackup--server--backuproot"></a>`backuproot`

Data type: `String`

directory for the backups.
defaults to '/srv/borgbackup'

Default value: `'/srv/borgbackup'`

##### <a name="-borgbackup--server--borguser"></a>`borguser`

Data type: `String`

the user to create for the remote borg 'agents'
to login via ssh
defaults to 'borgbackup'

Default value: `'borgbackup'`

##### <a name="-borgbackup--server--borggroup"></a>`borggroup`

Data type: `String`

the group of the borguser
defaults to 'borgbackup'

Default value: `'borgbackup'`

##### <a name="-borgbackup--server--borghome"></a>`borghome`

Data type: `String`

where the borgs live ;)
the homedirectory of the borg user

Default value: `'/var/lib/borgbackup'`

##### <a name="-borgbackup--server--user_ensure"></a>`user_ensure`

Data type: `Boolean`

if true (default) the $borguser is created

Default value: `true`

##### <a name="-borgbackup--server--authorized_keys_target"></a>`authorized_keys_target`

Data type: `String`

target for authorized_keys

Default value: `'/var/lib/borgbackup/authorized-keys'`

##### <a name="-borgbackup--server--authorized_keys_define"></a>`authorized_keys_define`

Data type: `String`

resource to create the authorized-keys file
defaults to 'borgbackup::authorized_key'
if you do not want to manage the authorized-keys file
set this to ''

Default value: `'borgbackup::authorized_key'`

##### <a name="-borgbackup--server--authorized_keys"></a>`authorized_keys`

Data type: `Hash`

Hash of keys to add to authorized-keys file
defaults to {}

Default value: `{}`

##### <a name="-borgbackup--server--authorized_keys_defaults"></a>`authorized_keys_defaults`

Data type: `Hash`

Hash of default parameters to generate the
authorized-keys file
defaults to {}

Default value: `{}`

## Defined types

### <a name="borgbackup--addtogit"></a>`borgbackup::addtogit`

internal define to add a repo to git.

#### Parameters

The following parameters are available in the `borgbackup::addtogit` defined type:

* [`passphrase`](#-borgbackup--addtogit--passphrase)
* [`reponame`](#-borgbackup--addtogit--reponame)

##### <a name="-borgbackup--addtogit--passphrase"></a>`passphrase`

Data type: `String`

passphrase to set.
if set to 'random', a random passphrase is generated

##### <a name="-borgbackup--addtogit--reponame"></a>`reponame`

Data type: `String`

the name of the repository

### <a name="borgbackup--archive"></a>`borgbackup::archive`

This class creates an archive in a repo

#### Parameters

The following parameters are available in the `borgbackup::archive` defined type:

* [`reponame`](#-borgbackup--archive--reponame)
* [`archive_name`](#-borgbackup--archive--archive_name)
* [`pre_commands`](#-borgbackup--archive--pre_commands)
* [`post_commands`](#-borgbackup--archive--post_commands)
* [`create_compression`](#-borgbackup--archive--create_compression)
* [`create_filter`](#-borgbackup--archive--create_filter)
* [`create_options`](#-borgbackup--archive--create_options)
* [`create_excludes`](#-borgbackup--archive--create_excludes)
* [`create_includes`](#-borgbackup--archive--create_includes)
* [`stdin_cmd`](#-borgbackup--archive--stdin_cmd)
* [`do_prune`](#-borgbackup--archive--do_prune)
* [`prune_options`](#-borgbackup--archive--prune_options)
* [`keep_last`](#-borgbackup--archive--keep_last)
* [`keep_hourly`](#-borgbackup--archive--keep_hourly)
* [`keep_daily`](#-borgbackup--archive--keep_daily)
* [`keep_weekly`](#-borgbackup--archive--keep_weekly)
* [`keep_monthly`](#-borgbackup--archive--keep_monthly)
* [`keep_yearly`](#-borgbackup--archive--keep_yearly)

##### <a name="-borgbackup--archive--reponame"></a>`reponame`

Data type: `String`

The name of the repo to add the archive
defaults to $::fqdn, the default repo created
by including borgbackup without parameters

Default value: `$facts['networking']['fqdn']`

##### <a name="-borgbackup--archive--archive_name"></a>`archive_name`

Data type: `String`

The name of the archive.
Defaults to $title

Default value: `$title`

##### <a name="-borgbackup--archive--pre_commands"></a>`pre_commands`

Data type: `Array`

Array of commands to run before the backup run
Defaults to []

Default value: `[]`

##### <a name="-borgbackup--archive--post_commands"></a>`post_commands`

Data type: `Array`

Array of commands to run after the backup run
Defaults to []

Default value: `[]`

##### <a name="-borgbackup--archive--create_compression"></a>`create_compression`

Data type: `String`

the compression to use for create.
Set to '' if no compresseion should be applied.
Defaults to 'lz4'

Default value: `'lz4'`

##### <a name="-borgbackup--archive--create_filter"></a>`create_filter`

Data type: `String`

Filter items to display for create commnd.
Set to '' if no filter should be applied.
Defaults to 'AME' (show Added, Modified and Error files)

Default value: `'AME'`

##### <a name="-borgbackup--archive--create_options"></a>`create_options`

Data type: `Array`

Array of additional options to add to the create command.
Each item will be prefixed with '--' (means use long name !)
Defaults to ['verbose', 'list', 'stats', 'show-rc', 'exclude-caches']

Default value: `['verbose', 'list', 'stats', 'show-rc', 'exclude-caches']`

##### <a name="-borgbackup--archive--create_excludes"></a>`create_excludes`

Data type: `Array`

Array of excludes
Defaults to []
needs to be [] if stdin_cmd is used.

Default value: `[]`

##### <a name="-borgbackup--archive--create_includes"></a>`create_includes`

Data type: `Array`

Array of file to include
Defaults to []
needs to be [] if stdin_cmd is used.

Default value: `[]`

##### <a name="-borgbackup--archive--stdin_cmd"></a>`stdin_cmd`

Data type: `Optional[String[1]]`

command which is executed, stdout is used as
input to backup. defaults to undef
do not use together with $create_excludes and $create_includes

Default value: `undef`

##### <a name="-borgbackup--archive--do_prune"></a>`do_prune`

Data type: `Boolean`

if true, prune will be run after the create command.
Defaults to true

Default value: `true`

##### <a name="-borgbackup--archive--prune_options"></a>`prune_options`

Data type: `Array`

Array of additional options to add to the prune command.
Each item will be prefixed with '--' (means use long name !)
Defaults to ['list', 'show-rc']

Default value: `['list', 'show-rc']`

##### <a name="-borgbackup--archive--keep_last"></a>`keep_last`

Data type: `Optional[Variant[String[1], Integer]]`

number of last archives to keep
Defaults to undef

Default value: `undef`

##### <a name="-borgbackup--archive--keep_hourly"></a>`keep_hourly`

Data type: `Optional[Variant[String[1], Integer]]`

number of hourly archives to keep
Defaults to undef

Default value: `undef`

##### <a name="-borgbackup--archive--keep_daily"></a>`keep_daily`

Data type: `Variant[String, Integer]`

number of daily archives to keep
Set to '' if this option should not be added
Defaults to 7

Default value: `7`

##### <a name="-borgbackup--archive--keep_weekly"></a>`keep_weekly`

Data type: `Variant[String, Integer]`

number of weekly archives to keep
Set to '' if this option should not be added
Defaults to 4

Default value: `4`

##### <a name="-borgbackup--archive--keep_monthly"></a>`keep_monthly`

Data type: `Variant[String, Integer]`

number of monthly archives to keep
Set to '' if this option should not be added
Defaults to 6

Default value: `6`

##### <a name="-borgbackup--archive--keep_yearly"></a>`keep_yearly`

Data type: `Optional[Variant[String[1], Integer]]`

number of yearly archives to keep
Defaults to undef (no yearly is kept)

Default value: `undef`

### <a name="borgbackup--authorized_key"></a>`borgbackup::authorized_key`

Internal define to handle the authorized keys
from borgbackup::server

for borgbackup dokumentation see:
  http://borgbackup.readthedocs.io/en/stable/usage/serve.html

#### Parameters

The following parameters are available in the `borgbackup::authorized_key` defined type:

* [`backuproot`](#-borgbackup--authorized_key--backuproot)
* [`target`](#-borgbackup--authorized_key--target)
* [`command`](#-borgbackup--authorized_key--command)
* [`reponame`](#-borgbackup--authorized_key--reponame)
* [`keys`](#-borgbackup--authorized_key--keys)
* [`restrict_to_path`](#-borgbackup--authorized_key--restrict_to_path)
* [`restrict_to_repository`](#-borgbackup--authorized_key--restrict_to_repository)
* [`append_only`](#-borgbackup--authorized_key--append_only)
* [`storage_quota`](#-borgbackup--authorized_key--storage_quota)
* [`restricts`](#-borgbackup--authorized_key--restricts)
* [`env_vars`](#-borgbackup--authorized_key--env_vars)

##### <a name="-borgbackup--authorized_key--backuproot"></a>`backuproot`

Data type: `String`

the directory where all the backups should be

##### <a name="-borgbackup--authorized_key--target"></a>`target`

Data type: `String`

the target authorized_keys file

##### <a name="-borgbackup--authorized_key--command"></a>`command`

Data type: `String`

the command to restrict to
defaults to 'borg serve'

Default value: `'borg serve'`

##### <a name="-borgbackup--authorized_key--reponame"></a>`reponame`

Data type: `String`

the name of the repo, defaults to $title

Default value: `$title`

##### <a name="-borgbackup--authorized_key--keys"></a>`keys`

Data type: `Array`

the ssh public keys to grant access with this configuration
defaults to []

Default value: `[]`

##### <a name="-borgbackup--authorized_key--restrict_to_path"></a>`restrict_to_path`

Data type: `String`

restrict repository access to PATH.
Access to all sub-directories is granted implicitly;
can be set to:
'' or no: option not used
'yes': set to ${backuproot}/${reponame}
or any path to set.
defaults to 'no'

Default value: `'no'`

##### <a name="-borgbackup--authorized_key--restrict_to_repository"></a>`restrict_to_repository`

Data type: `String`

restrict repository access. Only the repository located at
PATH (no sub-directories are considered) is accessible.
can be set to:
'' or no: option not used
'yes': set to ${backuproot}/${reponame}
or any path to set.
defaults to 'yes'

Default value: `'yes'`

##### <a name="-borgbackup--authorized_key--append_only"></a>`append_only`

Data type: `Boolean`

only allow appending to repository segment files
Defaults to false

Default value: `false`

##### <a name="-borgbackup--authorized_key--storage_quota"></a>`storage_quota`

Data type: `Optional[String[1]]`

Override storage quota of the repository (e.g. 5G, 1.5T).
When a new repository is initialized, sets the storage quota
on the new repository as well. Default: no quota.

Default value: `undef`

##### <a name="-borgbackup--authorized_key--restricts"></a>`restricts`

Data type: `Array`

ssh restrictions to set.
defaults to ['restrict'] this needs openssh-server > 7.2
if openssh-server < 7.2 use:
['no-port-forwarding','no-X11-forwarding','no-pty',
 'no-agent-forwarding','no-user-rc']

Default value: `['restrict']`

##### <a name="-borgbackup--authorized_key--env_vars"></a>`env_vars`

Data type: `Hash`

Hash of environment variables to set
defaults to {}

Default value: `{}`

### <a name="borgbackup--repo"></a>`borgbackup::repo`

This class initializes a backup run

#### Parameters

The following parameters are available in the `borgbackup::repo` defined type:

* [`reponame`](#-borgbackup--repo--reponame)
* [`target`](#-borgbackup--repo--target)
* [`passphrase`](#-borgbackup--repo--passphrase)
* [`passcommand`](#-borgbackup--repo--passcommand)
* [`env_vars`](#-borgbackup--repo--env_vars)
* [`encryption`](#-borgbackup--repo--encryption)
* [`append_only`](#-borgbackup--repo--append_only)
* [`storage_quota`](#-borgbackup--repo--storage_quota)
* [`archives`](#-borgbackup--repo--archives)
* [`icinga_old`](#-borgbackup--repo--icinga_old)
* [`crontab_define`](#-borgbackup--repo--crontab_define)
* [`crontabs`](#-borgbackup--repo--crontabs)
* [`check_host`](#-borgbackup--repo--check_host)

##### <a name="-borgbackup--repo--reponame"></a>`reponame`

Data type: `String`

the name of the repo
Defaults to $title

Default value: `$title`

##### <a name="-borgbackup--repo--target"></a>`target`

Data type: `String`

the target where to put the backup (env BORG_REPO)

Default value: `' '`

##### <a name="-borgbackup--repo--passphrase"></a>`passphrase`

Data type: `Optional[String]`

the passphrase to use for the repo
if empty (the default, a random pasphrase is generated
and saved gpg encrypted in a git repo. see
borgbackup::git for more information.

Default value: `undef`

##### <a name="-borgbackup--repo--passcommand"></a>`passcommand`

Data type: `String`

a command to get the password of the repo
defaults to 'default' which creates a
passcommand to extract the key from the gitrepo.

Default value: `'default'`

##### <a name="-borgbackup--repo--env_vars"></a>`env_vars`

Data type: `Hash`

additional environment variables to set
before the execution of borg and other commands.
defaults to {}
for remote repositories, set this to:
{ BORG_RSH: 'ssh -i /etc/borgbackup/.ssh/YOUR_KEY' }

Default value: `{}`

##### <a name="-borgbackup--repo--encryption"></a>`encryption`

Data type: `String`

the encryption for the backup.
defaults to 'keyfile'

Default value: `'keyfile'`

##### <a name="-borgbackup--repo--append_only"></a>`append_only`

Data type: `Boolean`

if true, an append_only repo is created (no purge)
defaults to false

Default value: `false`

##### <a name="-borgbackup--repo--storage_quota"></a>`storage_quota`

Data type: `Optional[String[1]]`

storage quota to set defaults to undef (no quota)

Default value: `undef`

##### <a name="-borgbackup--repo--archives"></a>`archives`

Data type: `Hash`

Hash of archives to create for this repo
See ::borgbackup::archive for options
$reponame is added as default.

Default value: `{}`

##### <a name="-borgbackup--repo--icinga_old"></a>`icinga_old`

Data type: `Integer`

you can run a rudimentary icinga/nagios check
to see if a repo is old. this parameter
after how many seconds a repo is considered old
defaults to 90000 (25h)

Default value: `90000`

##### <a name="-borgbackup--repo--crontab_define"></a>`crontab_define`

Data type: `String`

resource used to create a crontab entry
defaults to 'cron'
set this to a resource to create systemd timers
if you prefer systemd timers
if set to '' no cron job will be generated

Default value: `'cron'`

##### <a name="-borgbackup--repo--crontabs"></a>`crontabs`

Data type: `Hash`

parameters for $crontab_define
defaults to {}
which if crontab_define is 'cron' (the default)
creates a nightly cronjob for doing backup with:
cron { "borgbackup run ${reponame}":
  command => "${configdir}/repo_${reponame}.sh run",
  user    => 'root',
  hour    => fqdn_rand(3,'borgbackup'),
  minute  => fqdn_rand(60,'borgbackup'),
}

Default value: `{}`

##### <a name="-borgbackup--repo--check_host"></a>`check_host`

Data type: `Optional[String]`

if set to an ip address or a hostname, then a function
checks if this host is reachable by opening a socket to
port 22 (ssh). If this fails, the sope of this define
is set to noop.
Set checkhost equal to your remote backuphost to avoid
a fail of your regular puppetruns if the backuphost is
not reachable.
defaults to '' means do not check.

Default value: `undef`

## Functions

### <a name="borgbackup--noop_connection"></a>`borgbackup::noop_connection`

Type: Ruby 4.x API

Remark: This function is inspired by the trlinkin-noop module (https://forge.puppet.com/trlinkin/noop)

#### `borgbackup::noop_connection(String[1] $bb_server)`

Remark: This function is inspired by the trlinkin-noop module (https://forge.puppet.com/trlinkin/noop)

Returns: `Boolean` true on success

##### `bb_server`

Data type: `String[1]`

the server to check

## Tasks

### <a name="check"></a>`check`

verifies the consistency of a borg repository and the corresponding archives

**Supports noop?** false

#### Parameters

##### `reponame`

Data type: `Optional[String]`

The name of the repository if not set, $::fqdn is used

### <a name="info"></a>`info`

displays detailed information about the borg repo

**Supports noop?** false

#### Parameters

##### `reponame`

Data type: `Optional[String]`

The name of the repository if not set, $::fqdn is used

### <a name="list"></a>`list`

lists the contents of the nodes borg repository

**Supports noop?** false

#### Parameters

##### `reponame`

Data type: `Optional[String]`

The name of the repository if not set, $::fqdn is used

